==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebComponentValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescription } from "./WebComponentValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentValueChangedEventArgsDescriptionMetadata.c(WebComponentValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebComponentValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebComponentValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentValueChangedEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "String");
    };
    WebComponentValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentValueChangedEventArgsDescriptionMetadata.b(a);
        a.ad("WebComponentValueChangedEventArgs", function () { return new WebComponentValueChangedEventArgsDescription(); });
        a.ac("WebComponentValueChangedEventArgs", WebComponentValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentValueChangedEventArgsDescriptionMetadata, 'WebComponentValueChangedEventArgsDescriptionMetadata');
    WebComponentValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentValueChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebComponentValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescription } from "./WebComponentValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentValueChangedEventArgsDescriptionMetadata.c(WebComponentValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebComponentValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebComponentValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentValueChangedEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "String");
    };
    WebComponentValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentValueChangedEventArgsDescriptionMetadata.b(a);
        a.ae("WebComponentValueChangedEventArgs", function () { return new WebComponentValueChangedEventArgsDescription(); });
        a.ad("WebComponentValueChangedEventArgs", WebComponentValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentValueChangedEventArgsDescriptionMetadata, 'WebComponentValueChangedEventArgsDescriptionMetadata');
    WebComponentValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentValueChangedEventArgsDescriptionMetadata };
